@@ -18,11 +18,16 @@ use Data::Context::BEM::Instance;
 use Template;
 use File::ShareDir qw/module_dir dist_dir/;
 use Path::Tiny;
+use JSON::XS;
 
-our $VERSION = version->new('0.0.6');
+our $VERSION = version->new('0.1.1');
 
 extends 'Data::Context';
 
+has '+action_class' => (
+    default => 'Data::Context::BEM::Block',
+);
+
 has '+instance_class' => (
     default => 'Data::Context::BEM::Instance',
 );
@@ -78,7 +83,7 @@ around get => sub {
 };
 
 sub get_html {
-    my ($self, $path, $args, $params) = @_;
+    my ($self, $path, $params) = @_;
 
     # get processed data
     my $instance = $self->get_instance($path, $params);
@@ -117,7 +122,7 @@ sub get_html {
 }
 
 sub get_styles {
-    my ($self, $path, $args, $params) = @_;
+    my ($self, $path, $params) = @_;
 
     # get processed data
     my $instance = $self->get_instance($path, $params);
@@ -147,7 +152,7 @@ sub get_styles {
 }
 
 sub get_scripts {
-    my ($self, $path, $args, $params) = @_;
+    my ($self, $path, $params) = @_;
 
     # get processed data
     my $instance = $self->get_instance($path, $params);
@@ -199,13 +204,15 @@ sub set_template_path {
         $self->log->debug($block);
         next if !$self->block_module($block);
 
-        my $dir = module_dir( $self->block_module($block) );
-        $self->log->info( 'module_dir ' . Dumper { $block => $dir } ) if $self->debug <= 2;
-        next if !$dir || !-d $dir;
+        eval {
+            my $dir = module_dir( $self->block_module($block) );
+            $self->log->info( 'module_dir ' . Dumper { $block => $dir } ) if $self->debug <= 2;
+            next if !$dir || !-d $dir;
 
-        push @paths, $dir;
+            push @paths, $dir;
+        };
     }
-        push @paths, dist_dir('Data-Context-BEM');
+    push @paths, dist_dir('Data-Context-BEM');
 
     # construct page extras
     my @extras;
@@ -247,10 +254,21 @@ sub class {
         }
     }
 
+    push @class, $block->{class} if $block->{class};
+
     # TODO make this work for elements
     return join ' ', @class;
 }
 
+sub json {
+    my ($self, $block) = @_;
+    my $json = eval { JSON::XS->new->utf8->relaxed->shrink->encode($block); };
+    if ($@) {
+        $json = qq/{error:"$@"}/;
+    }
+    return $json;
+}
+
 sub _template {
     my ($self) = @_;
 
@@ -272,7 +290,7 @@ Data::Context::BEM - A Perl implementation of BEM
 
 =head1 VERSION
 
-This documentation refers to Data::Context::BEM version 0.0.6
+This documentation refers to Data::Context::BEM version 0.1.1
 
 =head1 SYNOPSIS
 
@@ -320,7 +338,7 @@ Returns a module that belongs to a block (if one exists)
 
 =head3 C<set_template_path ( $instance, $device_path )>
 
-Fora given L<Data::Context::BEM::Instance> sets the L<Template> path based
+For a given L<Data::Context::BEM::Instance> sets the L<Template> path based
 on the specified C<template_path> and the blocks used.
 
 =head3 C<get_template ($block)>
@@ -335,6 +353,10 @@ Dumps the passed objects to the log file
 
 Returns the classes for a block.
 
+=head3 C<json ($block)>
+
+Returns the block JSON encoded
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
