@@ -15,7 +15,14 @@ use List::Util;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
-our $VERSION = version->new('0.0.6');
+extends 'Data::Context::Actions';
+
+our $VERSION = version->new('0.1.1');
+
+sub get_data {
+    my ($self, $value, $vars, $path, $instance) = @_;
+    return $value;
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -29,7 +36,7 @@ Data::Context::BEM::Block - The base module for custom BEM block handlers
 
 =head1 VERSION
 
-This documentation refers to Data::Context::BEM::Block version 0.0.6
+This documentation refers to Data::Context::BEM::Block version 0.1.1
 
 =head1 SYNOPSIS
 
@@ -43,6 +50,10 @@ This documentation refers to Data::Context::BEM::Block version 0.0.6
 
 =head1 SUBROUTINES/METHODS
 
+=head2 C<get_data ($value, $vars, $path, $instance)>
+
+Just returns $value unchanged.
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
