@@ -19,7 +19,7 @@ use Data::Context::BEM::Merge;
 
 extends 'Data::Context::Instance';
 
-our $VERSION = version->new('0.0.6');
+our $VERSION = version->new('0.1.1');
 
 has blocks => (
     is      => 'rw',
@@ -39,7 +39,7 @@ around process_data => sub {
         $data->{processed} = 1;
     }
 
-    return $orig->($count, $data, $path);
+    return $self->$orig($count, $data, $path);
 };
 
 sub _merger {
@@ -60,7 +60,7 @@ Data::Context::BEM::Instance - An instance of a BEM script
 
 =head1 VERSION
 
-This documentation refers to Data::Context::BEM::Instance version 0.0.6
+This documentation refers to Data::Context::BEM::Instance version 0.1.1
 
 =head1 SYNOPSIS
 
