@@ -15,7 +15,7 @@ use List::MoreUtils qw/uniq pairwise/;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
-our $VERSION = version->new('0.0.6');
+our $VERSION = version->new('0.1.1');
 
 sub merge {
     my ($self, $child, $parent) = @_;
@@ -24,6 +24,9 @@ sub merge {
         return $child;
     }
     elsif ( ref $child eq 'ARRAY' ) {
+        if ( ref $parent ne 'ARRAY' ) {
+            $parent = [];
+        }
         my $new = [];
         my $max_child  = @$child  - 1;
         my $max_parent = @$parent - 1;
@@ -71,7 +74,7 @@ Data::Context::BEM::Merge - Merge algorithm that merges arrays (not appending th
 
 =head1 VERSION
 
-This documentation refers to Data::Context::BEM::Merge version 0.0.6
+This documentation refers to Data::Context::BEM::Merge version 0.1.1
 
 =head1 SYNOPSIS
 
